const db = require("../models");
const Game = db.games;

// Create and Save a new Game
exports.createGame = (req, res) => {
  // Validate request
  if (!req.body.title) {
    res.status(400).send({ message: "Content can not be empty!" });
    return;
  }

  // Create a Game
  const game = new Game({
    title: req.body.title,
    active: req.body.active ? req.body.active : false,
    turns: req.body.turns ? req.body.turns : 1,
    type: req.body.type,
    players: req.body.players,
    maxPlayers: req.body.maxPlayers ? req.body.maxPlayers : 2
  });

  // Save Game in the database
  game.save(game).then(data => {
      res.send(data);
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while creating the Game. (err. 5xx)"
      });
    });
};

// Find Game/s by title.
exports.findAllGamesByTitle = (req, res) => {
  const title = req.query.title;
  var condition = title ? { title: { $regex: new RegExp(title), $options: "i" } } : {};

  Game.find(condition)
    .then(data => {
      res.send(data);
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while retrieving games."
      });
    });
};

// Find Game by id
exports.findOneGameById = (req, res) => {
  const id = req.params.id;

  Game.findById(id)
    .then(data => {
      if (!data)
        res.status(404).send({ message: "Not found Game with id " + id });
      else res.send(data);
    })
    .catch(err => {
      res
        .status(500)
        .send({ message: "Error retrieving Game with id=" + id + ": " + err });
    });
};

// Update a Game by the id in the request
exports.updateGameById = (req, res) => {
  if (!req.body) {
    return res.status(400).send({
      message: "Data to update can not be empty!"
    });
  }

  const id = req.params.id;

  Game.findByIdAndUpdate(id, req.body, { useFindAndModify: false })
    .then(data => {
      if (!data) {
        res.status(404).send({
          message: `Cannot update Game with id=${id}. Maybe Game was not found!`
        });
      } else res.send({ message: "Game was updated successfully." });
    })
    .catch(err => {
      res.status(500).send({
        message: "Error updating Game with id=" + id + ": " + err
      });
    });
};

// Delete a Game with the specified id in the request
exports.deleteGameById = (req, res) => {
  const id = req.params.id;

  Game.findByIdAndRemove(id, { useFindAndModify: false })
    .then(data => {
      if (!data) {
        res.status(404).send({
          message: `Cannot delete Game with id=${id}. Maybe Game was not found!`
        });
      } else {
        res.send({
          message: "Game was deleted successfully!"
        });
      }
    })
    .catch(err => {
      res.status(500).send({
        message: "Could not delete Game with id=" + id + ": " + err
      });
    });
};

// Delete all Games from the database.
exports.deleteAllGame = (req, res) => {
  Game.deleteMany({})
    .then(data => {
      res.send({
        message: `${data.deletedCount} Games were deleted successfully!`
      });
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while removing all games."
      });
    });
};

// Find all active Games
exports.findAllActiveGame = (req, res) => {
  Game.find({ active: true })
    .then(data => {
      res.send(data);
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while retrieving games."
      });
    });
};

// insert a new player into a game
exports.insertPlayerIntoGame = (req, res) => {
  const id = req.params.id;

  Game.findById(id)
    .then(data => {
      if (!data) {
        res.status(404).send({
          message: `Cannot update Game with id=${id}. Maybe Game was not found!`
        });
      } else {
        // add player to game
        const playerId = db.mongoose.Types.ObjectId(req.body.player);
        db.players.findById(playerId)
          .then(player => {
            data.players.push(player.id);
            data.save();
            res.send(data);
          })
          .catch(err => {
            res.status(500).send({
              message: "Error finding player: " + err
            });
          });
      }
    })
    .catch(err => {
      res.status(500).send({
        message: "Error updating Game with id=" + id + ": " + err
      });
    });
}

