const db = require("../models");
const Play = db.plays;

// Create and save new Play
exports.createPlay = (req, res) => {
    // Validate request
    if (!req.body) {
        res.status(400).send({ message: "Content can not be empty!" });
        return;
    }

    // Create a Play
    const play = new Play({
        game: db.mongoose.Types.ObjectId(req.body.game),
        player: db.mongoose.Types.ObjectId(req.body.player),
        move: req.body.move,
        turns: Number(req.body.turns),
    });

    Play.find({ game: play.game, player: play.player })
        .then(data => {
            if (data.length > 0) {
                res.status(400).send({ message: "Play already exists!" });
                return; // Detener la ejecución del controlador
            } else {
                // Save Play in the database
                return play.save();
            }
        })
        .then(savedPlay => {
            if (savedPlay) {
                res.send(savedPlay);
                return; // Detener la ejecución del controlador
            }
            res.status(500).send({
                message: "Some error occurred while creating the Play. (err. 5xx)"
            });
        })
        .catch(err => {
            res.status(500).send({
                message:
                    err.message || "Some error occurred while creating the Play. (err. 5xx)"
            });
        });

}

// Find all Play
exports.findAllPlays = (req, res) => {
    Play.find({})
        .then(data => {
            res.send(data);
        })
        .catch(err => {
            res.status(500).send({
                message:
                    err.message || "Some error occurred while retrieving plays."
            });
        });
}

// Delete all Play
exports.deleteAllPlays = (req, res) => {
    Play.deleteMany({})
        .then(data => {
            res.send({
                message: `${data.deletedCount} Plays were deleted successfully!`
            });
        })
        .catch(err => {
            res.status(500).send({
                message:
                    err.message || "Some error occurred while removing all plays."
            });
        });
}
