const db = require("../models");
const Player = db.players


// Create and Save a new Player
exports.createPlayer = (req, res) => {
  // Validate request
  if (!req.body.name) {
    res.status(400).send({ message: "Content can not be empty!" });
    return;
  }

  // Create a Player
  const player = new Player({
    name: req.body.name,
    ties: req.body.ties
  });

  // Save Player in the database
  player
    .save(player)
    .then(data => {
      res.send(data);
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while creating the Player."
      });
    });
}

// Retrieve all Players from the database.
exports.findAllPlayers = (req, res) => {
  const name = req.query.name;
  let condition = name ? { name: { $regex: new RegExp(name), $options: "i" } } : {};

  Player.find(condition)
    .then(data => {
      res.send(data);
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while retrieving players."
      });
    });
}

// Find a single Player with an id
exports.findOnePlayerById = (req, res) => {
  const id = req.params.id;

  Player.findById(id)
    .then(data => {
      if (!data)
        res.status(404).send({ message: "Not found Player with id " + id });
      else res.send(data);
    })
    .catch(err => {
      res
        .status(500)
        .send({ message: "Error retrieving Player with id=" + id });
    });
}


// Update a Player by the id in the request
exports.updatePlayerById = (req, res) => {
  if (!req.body) {
    return res.status(400).send({
      message: "Data to update can not be empty!"
    });
  }

  const id = req.params.id;

  Player.findByIdAndUpdate(id,  req.body, { useFindAndModify: false })
    .then(data => {
      if (!data) {
        res.status(404).send({
          message: `Cannot update Player with id=${id}. Maybe Player was not found!`
        });
      } else res.send({ message: "Player was updated successfully." });
    })
    .catch(err => {
      res.status(500).send({
        message: "Error updating Player with id=" + id
      });
    } );
};


// Delete a Player with the specified id in the request
exports.deletePlayerById = (req, res) => {
  const id = req.params.id;

  Player.findByIdAndRemove(id)
    .then(data => {
      if (!data) {
        res.status(404).send({
          message: `Cannot delete Player with id=${id}. Maybe Player was not found!`
        });
      } else {
        res.send({
          message: "Player was deleted successfully!"
        });
      }
    })
    .catch(err => {
      res.status(500).send({
        message: "Could not delete Player with id=" + id
      });
    });
}

// Delete all Players from the database.
exports.deleteAllPlayers = (req, res) => {
  Player.deleteMany({})
    .then(data => {
      res.send({
        message: `${data.deletedCount} Players were deleted successfully!`
      });
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while removing all players."
      });
    });
}


// Find all active Players
exports.findAllActivePlayer = (req, res) => {
  Player.find({ active: true })
    .then(data => {
      res.send(data);
    })
    .catch(err => {
      res.status(500).send({
        message:
          err.message || "Some error occurred while retrieving players."
      });
    });
}
