require("dotenv").config();
const express = require("express");
const axios = require("axios");
const cors = require("cors");

const app = express();

var corsOptions = {
  origin: ["http://localhost:8080","https://rps-frontend-firebase-48465.web.app"]
 };

 app.use(cors(corsOptions));

// parse requests of content-type - application/json
app.use(express.json());

// parse requests of content-type - application/x-www-form-urlencoded
app.use(express.urlencoded({ extended: true }));

const db = require("./app/models");

console.log(db.url);

db.mongoose
    .connect(db.url, {
      useNewUrlParser: true,
      useUnifiedTopology: true
    })
    .then(() => {
      console.log("Connected to the database!");
    })
    .catch(err => {
      console.log("Cannot connect to the database!", err);
      process.exit();
    });

// simple route
app.get("/", (req, res) => {
  res.json({ message: "Welcome to rps application." });
});

require("./app/routes/game.routes")(app);
require("./app/routes/player.routes")(app);
require("./app/routes/move.routes")(app);
require("./app/routes/play.routes")(app);
require("./app/routes/turn.routes")(app);
require("./app/routes/gameType.routes")(app);
require("./app/routes/challenge.routes")(app);
require("./app/routes/callback.routes")(app);
require("./app/routes/connect.routes")(app);

// set port, listen for requests
const PORT = process.env.PORT || 8080;
app.listen(PORT, () => {
  console.log(`Server is running on port ${PORT}.`);
});
