import axios from 'axios';
import {Game} from '@/interface/game';
import {GameType} from '@/interface/gameType';

const API_URL = 'https://http-nodejs-production-b29c.up.railway.app/api';
// axios.defaults.baseURL = API_URL;

// Crear instancias personalizadas de axios
const axiosMy = axios.create({
    baseURL: API_URL
});

async function initGameMoves(name: string) {
    try {
        const response = await axiosMy.post<GameType>('/moves', {
            params: {
                name: name
            }
        });
        return response.data;
    } catch (error) {
        console.log(error);
    }
}

async function getMoves() {
    console.log("getMoves");
    try {
        const response = await axiosMy.get<GameType>('/moves');
        return response.data;
    } catch (error) {
        console.log(error);
    }
}

async function getGameTypes() {
    try {
        const response = await axiosMy.get('/gameTypes');
        return response.data;
    } catch (error) {
        console.log(error);
    }
}

async function createGame(game: Game) {
    console.log("createGame");
    console.log(game);
    try {
        const response = await axiosMy.post('/games', game);
        return response.data;
    } catch (error) {
        console.log(error);
    }
}

async function getGamesByTitle() {
    try {
        const response = await axiosMy.get<Game>('/games');
        const game = response.data;
        return game;
    } catch (error) {
        console.log(error);
    }
}

async function findOneGameById(id: string) {
    try {
        const response = await axiosMy.get(`/games/${id}`);
        const game = response.data;
        console.log(game);
        return game;
    } catch (error) {
        console.log(error);
    }
}

async function createPlayer(player: string) {
    try {
        const response = await axiosMy.post('/players', player);
        const data = response.data;
        return data;
    } catch (error) {
        console.log(error);
    }
}

async function insertPlayerIntoGame(id: string, player: string) {
    try {
        const response = await axiosMy.post(`/games/${id}/player`, player);
        const data = response.data;
        console.log(data);
        return data;
    } catch (error) {
        console.log(error);
    }
}

async function createPlay(play: any) {
    try {
        const response = await axiosMy.post('/plays', play);
        const data = response.data;
        return data;
    } catch (error) {
        console.log(error);
    }
}

async function getPlays() {
    try {
        const response = await axiosMy.get('/plays');
        const data = response.data;
        return data;
    } catch (error) {
        console.log(error);
    }
}

async function sendChallenge(challenge: any) {
    const storedAccessToken = localStorage.getItem('salckAccessToken') || '';
    // const storedAccessToken = JSON.parse(storedAccessTokenString);
    console.log('challenge', challenge)
    console.log('storedAccessToken', storedAccessToken)

    try {
        if (!storedAccessToken) {
            return;
        }
        const response = await axiosMy.post('/challenge', {
            params: {
                text: challenge,
                url: storedAccessToken
            }
        });
        const data = response.data;
        console.log(data)
        return data;
    } catch (error) {
        console.log(error);
    }
}

async function getCallback(authorizationQuery: any) {
    try {
        const response = await axiosMy.get(`/callback?code=${authorizationQuery.code}`);
        const data = response.data;
        return data;
    } catch (error) {
        console.log(error);
    }
}

async function createConnect(hooksSlack: string, userUid: string) {
    try {
        const response = await axiosMy.post(`/connect`, {
            hooksSlack: hooksSlack,
            userUid: userUid
        });
        const data = response.data;
        return data;
    } catch (error) {
        console.log(error);
    }
}


async function findOneConnectUserUid(userUid: string) {
    try {
        const response = await axiosMy.get(`/connect/${userUid}`);
        const data = response.data;
        return data;
    } catch (error) {
        console.log(error);
    }
}

export default {
    initGameMoves,
    getMoves,
    getGameTypes,
    createGame,
    getGamesByTitle,
    createPlayer,
    findOneGameById,
    insertPlayerIntoGame,
    createPlay,
    getPlays,
    sendChallenge,
    getCallback,
    createConnect,
    findOneConnectUserUid
}
