import { shallowMount } from '@vue/test-utils';
import RPSGame from '@/components/rpsGameRoom.vue';

describe('RPSGame', () => {
    let wrapper: any;
    let playGameSpy: any;
    let getPlaysSpy: any;

    beforeEach(() => {
        const service = {
            getPlays: jest.fn().mockResolvedValue([
                { player: 'userId1', game: 'gameId1', move: 'rock' },
                { player: 'userId2', game: 'gameId1', move: 'paper' },
            ]),
        };
        wrapper = shallowMount(RPSGame, {
            mocks: {
                service,
            },
        });
        playGameSpy = jest.spyOn(wrapper.vm, 'play').mockImplementation();
        getPlaysSpy = jest.spyOn(service, 'getPlays');

        jest.clearAllMocks();
    });

    test('renders correctly', () => {
        expect(wrapper.element).toMatchSnapshot();
    });

    test('play the game is called', async () => {
        await wrapper.find('[data-testid="rock"]').trigger('click');
        expect(playGameSpy).toHaveBeenCalled();
    });

    test('matchResult returns the correct values', async () => {
        const userChoice = 'rock';
        const opponentChoice = 'paper';
        const matchResultSpy = jest.spyOn(wrapper.vm, 'matchResult');

        await wrapper.vm.matchResult(userChoice, opponentChoice);

        expect(matchResultSpy).toHaveBeenCalledWith(userChoice, opponentChoice);
        expect(matchResultSpy.mock.calls[0][0]).toBe(userChoice);
        expect(matchResultSpy.mock.calls[0][1]).toBe(opponentChoice);
        expect(wrapper.find('[data-testid="result"]').text()).toBe('You lose!');

        matchResultSpy.mockRestore();
    });
});
